wsireg.reg\_images package
==========================

RegImage base class
--------------------

.. automodule:: wsireg.reg_images.reg_image
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

wsireg.reg\_images.aics\_reg\_image module
------------------------------------------

.. automodule:: wsireg.reg_images.aics_reg_image
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.reg\_images.czi\_reg\_image module
-----------------------------------------

.. automodule:: wsireg.reg_images.czi_reg_image
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.reg\_images.loader module
--------------------------------

.. automodule:: wsireg.reg_images.loader
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.reg\_images.merge\_reg\_image module
-------------------------------------------

.. automodule:: wsireg.reg_images.merge_reg_image
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.reg\_images.np\_reg\_image module
----------------------------------------

.. automodule:: wsireg.reg_images.np_reg_image
   :members:
   :undoc-members:
   :show-inheritance:


wsireg.reg\_images.sitk\_reg\_image module
------------------------------------------

.. automodule:: wsireg.reg_images.sitk_reg_image
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.reg\_images.tifffile\_reg\_image module
----------------------------------------------

.. automodule:: wsireg.reg_images.tifffile_reg_image
   :members:
   :undoc-members:
   :show-inheritance:
